@@ -9,6 +9,7 @@ import re
 import json
 import webbrowser
 from PIL import Image, ImageEnhance
+import imageio
 from pathlib import Path
 import urllib.request
 import time
@@ -1128,16 +1129,7 @@ class MainWindow(QtWidgets.QMainWindow):
 
         self.actions.refresh.setEnabled(True)
 
-        # refresh: list all images and create mean img
 
-        # refresh: perform autosegmentation with loaded _meanImg (if micModeOn)
-
-
-        # refresh will check if sufficient new images were loaded or maybe just create mean image whenever clicked (unless there are no new images)
-
-        # next/prev image should now only find _mean.png files and automatically do the labeling
-
-        # maybe update
 
     def autosegmentation(self):
 
@@ -1147,10 +1139,10 @@ class MainWindow(QtWidgets.QMainWindow):
 
         if self.imagePath != None:
 
-            if not self.imagePath.endswith((".png", ".tiff")):
+            if not self.imagePath.endswith((".png", ".tiff", "tif")):
 
                 mbFormat = QtWidgets.QMessageBox(QtWidgets.QMessageBox.Warning, "Unsupported file format",
-                                                 "Please choose PNG or TIFF image file.",
+                                                 "Please choose PNG, TIF or TIFF image file.",
                                                  QtWidgets.QMessageBox.Ok)
                 mbFormat.exec()
 
@@ -1170,18 +1162,22 @@ class MainWindow(QtWidgets.QMainWindow):
                     im_output.save(osp.splitext(self.imagePath)[0] + "_curr.tiff", quality=100)
                     self.imagePath = osp.splitext(self.imagePath)[0] + "_curr.tiff"
                     self.loadFile(self.imagePath)
+                elif self.imagePath.endswith(".tif"):
+                    im_output.save(osp.splitext(self.imagePath)[0] + "_curr.tif", quality=100)
+                    self.imagePath = osp.splitext(self.imagePath)[0] + "_curr.tif"
+                    self.loadFile(self.imagePath)
 
         elif self.imagePath == None:
             self.openFile()
 
         if self.imagePath != None:
-            if not self.imagePath.endswith((".png", ".tiff")):
+            if not self.imagePath.endswith((".png", ".tiff", "tif")):
                 mbFormat = QtWidgets.QMessageBox(QtWidgets.QMessageBox.Warning, "Unsupported file format",
-                                                 "Please choose PNG or TIFF image file.",
+                                                 "Please choose PNG, TIF or TIFF image file.",
                                                  QtWidgets.QMessageBox.Ok)
                 mbFormat.exec()
 
-            if self.imagePath.endswith((".png", ".tiff")):
+            if self.imagePath.endswith((".png", ".tiff", "tif")):
                 im_path = self.imagePath.replace("\\", "/")
                 minArea, maxArea = self.minMaxNeuronValues
                 pred_main(self.imagePath.replace("\\", "/"), model=self.currentModel, minimal_area_neuron_in_pixels=minArea, maximal_area_neuron_in_pixels=maxArea)
@@ -1859,6 +1855,28 @@ class MainWindow(QtWidgets.QMainWindow):
             item.setCheckState(Qt.Checked if value else Qt.Unchecked)
 
     def loadFile(self, filename=None):
+        if filename is not None:
+            # tif file conversion to 8 bit png if tif was 16 bit
+            if filename.endswith("tif"):
+                image = imageio.imread(filename)
+
+                # downscaling to 8bit and upscaling for low max brightness
+                image = (image /(image.max() / 255)).astype('uint8')
+
+                filename = filename.replace(".tif", ".png")
+
+                imageio.imwrite(filename, image)
+
+            elif filename.endswith("tiff"):
+                image = imageio.imread(filename)
+
+                # downscaling to 8bit and upscaling for low max brightness
+                image = (image/(image.max()/255)).astype('uint8')
+
+                filename = filename.replace(".tiff", ".png")
+
+                imageio.imwrite(filename, image)
+
         """Load the specified file, or the last opened file if None."""
         # changing fileListWidget loads file
         if filename in self.imageList and (
@@ -2480,7 +2498,8 @@ class MainWindow(QtWidgets.QMainWindow):
 
 
         images = np.array([np.array(Image.open(self.lastOpenDir + "/"+fname)) for fname in imlist])
-        arr = np.array(np.mean(images, axis=(0)), dtype=np.uint8)
+        arr = np.array(np.mean(images, axis=(0)), dtype=np.uint16)
+        arr = (arr / (arr.max() / 255)).astype('uint8')
         out = Image.fromarray(arr)
 
         out.save(self.lastOpenDir + "/1-" + str(N) + "_mean.png")
